@@ -8,10 +8,10 @@ from togglee.strategies.main import strategy_maps
 
 
 class Togglee:
-    def __init__(self, url: str, refresh_rate: int, defaults: dict):
+    def __init__(self, url: str, refresh_rate: int, defaults: list):
         self._url = url
         self._refresh_rate = refresh_rate
-        self._toggles = defaults
+        self._toggles = map_json_to_toggles(defaults) if isinstance(defaults, list) else None
         self._thread = threading.Thread(target=self._scheduler_event)
         self._thread.daemon = True
         self._thread.start()
@@ -35,6 +35,6 @@ class Togglee:
     def _refresh_toggles(self):
         try:
             response = requests.get(self._url)
-            self._toggles = map_json_to_toggles(response.json())
+            self._toggles = map_json_to_toggles(response.json()['toggles'])
         except:
             pass
